import type { CancelablePromise } from "../core/CancelablePromise.js";
import type { BaseHttpRequest } from "../core/BaseHttpRequest.js";
export declare class WalletSubscriptionsService {
    readonly httpRequest: BaseHttpRequest;
    constructor(httpRequest: BaseHttpRequest);
    /**
     * Get wallet subscriptions
     * Get all wallet subscriptions.
     * @param page Specify the page number.
     * @param limit Specify the number of results to return per page.
     * @returns any Default Response
     * @throws ApiError
     */
    getAllWalletSubscriptions(page?: number, limit?: number): CancelablePromise<{
        result: Array<{
            id: string;
            /**
             * The chain ID of the subscription.
             */
            chainId: string;
            /**
             * A contract or wallet address
             */
            walletAddress: string;
            /**
             * Array of conditions to monitor for this wallet
             */
            conditions: Array<({
                type: 'token_balance_lt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            } | {
                type: 'token_balance_gt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            })>;
            webhook?: {
                url: string;
            };
            createdAt: string;
            updatedAt: string;
        }>;
    }>;
    /**
     * Add wallet subscription
     * Subscribe to wallet conditions.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    addWalletSubscription(requestBody?: ({
        /**
         * A chain ID ("137") or slug ("polygon-amoy-testnet"). Chain ID is preferred.
         */
        chain: string;
        /**
         * A contract or wallet address
         */
        walletAddress: string;
        /**
         * Array of conditions to monitor for this wallet
         */
        conditions: Array<({
            type: 'token_balance_lt';
            tokenAddress: (string | 'native');
            /**
             * The threshold value in wei
             */
            value: string;
        } | {
            type: 'token_balance_gt';
            tokenAddress: (string | 'native');
            /**
             * The threshold value in wei
             */
            value: string;
        })>;
    } & ({
        /**
         * Webhook URL to create a new webhook
         */
        webhookUrl: string;
        /**
         * Optional label for the webhook when creating a new one
         */
        webhookLabel?: string;
    } | {
        /**
         * ID of an existing webhook to use
         */
        webhookId: number;
    }))): CancelablePromise<{
        result: {
            id: string;
            /**
             * The chain ID of the subscription.
             */
            chainId: string;
            /**
             * A contract or wallet address
             */
            walletAddress: string;
            /**
             * Array of conditions to monitor for this wallet
             */
            conditions: Array<({
                type: 'token_balance_lt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            } | {
                type: 'token_balance_gt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            })>;
            webhook?: {
                url: string;
            };
            createdAt: string;
            updatedAt: string;
        };
    }>;
    /**
     * Update wallet subscription
     * Update an existing wallet subscription.
     * @param subscriptionId The ID of the wallet subscription to update.
     * @param requestBody
     * @returns any Default Response
     * @throws ApiError
     */
    updateWalletSubscription(subscriptionId: string, requestBody?: {
        /**
         * A chain ID ("137") or slug ("polygon-amoy-testnet"). Chain ID is preferred.
         */
        chain?: string;
        /**
         * A contract or wallet address
         */
        walletAddress?: string;
        /**
         * Array of conditions to monitor for this wallet
         */
        conditions?: Array<({
            type: 'token_balance_lt';
            tokenAddress: (string | 'native');
            /**
             * The threshold value in wei
             */
            value: string;
        } | {
            type: 'token_balance_gt';
            tokenAddress: (string | 'native');
            /**
             * The threshold value in wei
             */
            value: string;
        })>;
        webhookId?: (number | null);
    }): CancelablePromise<{
        result: {
            id: string;
            /**
             * The chain ID of the subscription.
             */
            chainId: string;
            /**
             * A contract or wallet address
             */
            walletAddress: string;
            /**
             * Array of conditions to monitor for this wallet
             */
            conditions: Array<({
                type: 'token_balance_lt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            } | {
                type: 'token_balance_gt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            })>;
            webhook?: {
                url: string;
            };
            createdAt: string;
            updatedAt: string;
        };
    }>;
    /**
     * Delete wallet subscription
     * Delete an existing wallet subscription.
     * @param subscriptionId The ID of the wallet subscription to update.
     * @returns any Default Response
     * @throws ApiError
     */
    deleteWalletSubscription(subscriptionId: string): CancelablePromise<{
        result: {
            id: string;
            /**
             * The chain ID of the subscription.
             */
            chainId: string;
            /**
             * A contract or wallet address
             */
            walletAddress: string;
            /**
             * Array of conditions to monitor for this wallet
             */
            conditions: Array<({
                type: 'token_balance_lt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            } | {
                type: 'token_balance_gt';
                tokenAddress: (string | 'native');
                /**
                 * The threshold value in wei
                 */
                value: string;
            })>;
            webhook?: {
                url: string;
            };
            createdAt: string;
            updatedAt: string;
        };
    }>;
}
